import React from 'react';
import styled from 'styled-components';

import { HiroColors } from '../../types';
import { clickable, colourable, secondary } from '../../utils';
import defaultTheme from '../../theme';

interface AlignedProps {
  align?: 'left' | 'right';
}

interface StyledButtonProps {
  color?: HiroColors;
  secondary?: boolean;
  disabled?: boolean;
}

export type ButtonProps = StyledButtonProps & AlignedProps;

export const StyledButton = styled.button<StyledButtonProps>(
  {
    minWidth: '100px',
    height: '35px',
    borderRadius: '3em',
    border: 'none',
    opacity: 1,
    outline: 'none',
    padding: '0 2em',
  },
  colourable,
  secondary,
  clickable,
);

StyledButton.defaultProps = {
  theme: defaultTheme,
};

export const AlignedDiv = styled.div<AlignedProps>((props) => ({
  textAlign: props.align,
  padding: '0.5em',
}));

export const Button: React.FC<ButtonProps> = (props) => {
  if (!props.align) {
    return <StyledButton {...props} />;
  }

  return (
    <AlignedDiv align={props.align}>
      <StyledButton {...props} />
    </AlignedDiv>
  );
};
